@@ -1,24 +1,19 @@
 package Fake::Encode;
 ######################################################################
 #
-# Fake::Encode - Fake Encode module support for perl 5.00503
+# Fake::Encode - Fake Encode module for compatible scripting
 #
 # http://search.cpan.org/dist/Fake-Encode/
 #
-# Copyright (c) 2016 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2016, 2017 INABA Hitoshi <ina@cpan.org> in a CPAN
 ######################################################################
 
-$Fake::Encode::VERSION = '0.01';
+$VERSION =
+$VERSION = '0.02';
 
+BEGIN { pop @INC if $INC[-1] eq '.' } # CVE-2016-1238: Important unsafe module load path flaw
 use 5.00503;
 use strict;
-use Carp;
-
-sub import {
-    if ($] > 5.00503) {
-        Carp::croak "@{[__FILE__]} works on perl 5.00503 only.\n";
-    }
-}
 
 sub Encode::decode {
     my(undef, $human_readable_string) = @_;
@@ -40,11 +35,10 @@ __END__
 
 =head1 NAME
 
-Fake::Encode - Fake Encode module support for perl 5.00503
+Fake::Encode - Fake Encode module for compatible scripting
 
 =head1 SYNOPSIS
 
-  use 5.00503;
   use Fake::Encode;
   use DBI;
   
@@ -62,7 +56,7 @@ Encode::encode() and Encode::decode().
 
 =head1 AUTHOR
 
-INABA Hitoshi E<lt>ina@cpan.orgE<gt>
+INABA Hitoshi E<lt>ina@cpan.orgE<gt> in a CPAN
 
 This project was originated by INABA Hitoshi.
 
